use-feature
Primitive sequence and genomic feature vocabulary.
use-feature stores descriptive feature identifiers, names, kinds, optional genomic ranges, and deterministic attributes. It does not build annotation pipelines, infer features, parse GFF/GTF, or connect to databases.
use use_feature::{FeatureKind, FeatureName, SequenceFeature};
use use_genomic_range::{GenomicPosition, GenomicRange};
let range = GenomicRange::new(GenomicPosition::new(10), GenomicPosition::new(20)).unwrap();
let feature = SequenceFeature::new(FeatureKind::Gene, FeatureName::new("BRCA1 region").unwrap())
.with_range(range.clone());
assert_eq!(feature.kind(), &FeatureKind::Gene);
assert_eq!(feature.range(), Some(&range));Structs
- Feature
Id - A non-empty feature identifier.
- Feature
Name - A non-empty feature name.
- Sequence
Feature - A sequence or genomic feature with optional range and deterministic attributes.
Enums
- Feature
Kind - A descriptive feature kind.
- Feature
Value Error - Error returned by feature vocabulary constructors.